Description Usage Format Source Examples
Data from the Water Corporation of Western Australia. They state the following about these data on their website: "Streamflow is the amount of water entering our dams from our catchments and is measured by changing water storage levels." This dataset has the annual averages of these storage levels.
1 |
A data.frame consisting of the following variable:
waterwater level (in GL)
yearyear
wtmin1water level in the previous year (GL)
These data are provided by the Water Corporation of Western Australia and can be found here: https://www.watercorporation.com.au/water-supply/rainfall-and-dams/streamflow/streamflowhistorical
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.